import { Component } from '@angular/core';
import vfmLoader from 'vfmloader';

type Cell = any;
type Sheet = {
  name: String,
  data: {}[],
  columns: Columns,
  active: Boolean,
};
type Columns = Array<{
  data: string,
}>;

@Component({
	selector: 'workbook',
	template: `
  <div #loadFileBlock>
    <input *ngIf="!sheets.length" type="file" (change)="onFileChange($event)" multiple="false" />
    <div *ngFor='let hotTable of sheets; let i = index;'>
      <hotTable
        [hidden]="!hotTable.active"
        [data]="hotTable.data"
        [columns]="hotTable.columns"
        [options]="options">
      </hotTable>
    </div>
    <div *ngFor='let hotTable of sheets; let i = index;'>
      <button (click)="selectSheet(i)" name="{{i}}">{{hotTable.name}}</button>
    </div>
  </div>
	`
})

export class WorkbookComponent {

  /** Compare strategy **/
  // load file
  // State structure?
  // A and B or array?
  // sheets_1 v sheets_2
  // [[Sheet[]], [Sheet[]]]

  private sheets: Sheet[] = [];
  private columns: Columns = null;

  constructor() {
    if (localStorage.sheets) {
      this.sheets = JSON.parse(localStorage.sheets);
    }
  }

	onFileChange(evt: any) {
		/* wire up file reader */
		const target: DataTransfer = <DataTransfer>(evt.target);
		if (target.files.length != 1) {
      throw new Error("Cannot upload multiple files on the entry")
    };
    vfmLoader.loadFile(target.files[0], (sheets) => {
      this.sheets = sheets;
      localStorage.setItem('sheets', JSON.stringify(sheets));
      return;
    });
	}

  selectSheet(i: number) {
    this.sheets.forEach((tab) => {
      tab.active = false;
    });
    this.sheets[i].active = true;
  }

  private options: any = {
    stretchH: 'all',
  };
}
